==> aiokit-0.2.11.tgz: package/src/components/Input/Input.tsx <==
import React, {Component} from 'react';
import styled, {css} from 'styled-components';

function joinedBorderStyle(joined: IInputProps['joined']) {
  switch (joined) {
    case 'top':
      return css`
        border-radius: 4px 4px 0 0;
      `;
    case 'left':
      return css`
        border-radius: 4px 0 0 4px;
      `;
    case 'bottom':
      return css`
        border-top: 0;
        border-radius: 0 0 4px 4px;
      `;
    case 'right':
      return css`
        border-left: 0;
        border-radius: 0 4px 4px 0;
      `;
    default:
      return css`
        border-radius: 4px;
      `;
  }
}

function borderStyle(flat: boolean, error: string, theme: any): string {
  const {border, danger: red} = theme.color;

  if (flat) {
    return '1px solid transparent';
  }

  return error ? `1px solid ${red}` : `1px solid ${border}`;
}

const InputContainer = styled.div`
  position: relative;
  background-color: ${({theme}) => theme.color.background};
  color: ${({theme}) => theme.color.text};
  min-height: ${({theme}) => theme.font.element};
  border-radius: 4px;
  border: ${({theme, flat, error}) => borderStyle(flat, error, theme)};
  box-sizing: content-box;
  ${({joined}) => joined ? joinedBorderStyle(joined) : null}
`;

const InputField = styled.input`
  outline: none;
  border: 0;
  position: relative;
  width: 100%;
  top: 0;
  left: 0;
  font-family: ${({theme}) => theme.font.family};
  font-size: 16px;
  background-color: transparent;
  padding: ${({theme, labeled}) => labeled ? `28px 20px 10px 20px` : theme.padding.element};
  box-sizing: border-box;
  resize: none;

  &::placeholder {
    color: ${({theme}) => theme.color.placeholder};
    font-size: 14px;
  };
`;

const InputLabel = styled.label`
  position: absolute;
  top: 0;
  left: 0;
  color: ${({theme, error}) => error ? theme.color.danger : theme.color.placeholder};
  font-family: ${({theme}) => theme.font.family};
  font-size: ${({active}) => active ? '12px' : '14px'};
  padding: ${({theme, active}) => active ? `10px ${theme.padding.element}` : theme.padding.element};
  transition-property: padding-top, font-size;
  transition-duration: .2s;
`;

const TextArea = styled.textarea``;

export interface IInputProps {
  onFocus?: (event: React.SyntheticEvent) => void;
  onBlur?: (event: React.SyntheticEvent) => void;
  onChange?: (value: string, name: string) => void;
  value?: string;
  name: string;
  multiline?: boolean;
  placeholder?: string;
  type?: 'text' | 'email' | 'password' | 'number';
  label?: string;
  flat?: boolean;
  joined?: 'top' | 'left' | 'bottom' | 'right';
  error?: string;
  rows?: number;
}

export class Input extends Component <IInputProps, any> {
  public static defaultProps = {
    onChange: () => null,
    onBlur: () => null,
    onFocus: () => null,
  };

  public state = {
    value: this.props.value || '',
    prevValue: this.props.value || '',
    active: !!this.props.value,
  };

  public static getDerivedStateFromProps(props, state) {
    const {value} = props;

    if (value !== state.prevValue) {
      return {
        value,
        prevValue: value,
        active: !!value,
      };
    }

    return null;
  }

  private onChange = (event) => {
    const value = event.target.value;

    this.setState({
      value,
    });

    this.props.onChange(value, event.target.name);
  };

  private onFocus = (event) => {
    event.persist();

    this.setState({
      active: true,
    });

    this.props.onFocus(event);
  };

  private onBlur = (event) => {
    event.persist();

    this.setState({
      active: this.state.value !== '',
    });

    this.props.onBlur(event);
  };

  public render() {
    const {
      name,
      multiline,
      placeholder,
      type,
      label,
      error,
      flat,
      joined,
      ...rest
    } = this.props;
    const {active, value} = this.state;

    return (
      <InputContainer
        error={error}
        flat={flat}
        joined={joined}
      >
        {error ?
          <InputLabel active={active} error={error}>{error}</InputLabel>
          : <InputLabel active={active}>{label}</InputLabel>
        }
        <InputField
          {...rest}
          as={multiline ? TextArea : null}
          name={name}
          placeholder={placeholder}
          value={value}
          onChange={this.onChange}
          onFocus={this.onFocus}
          onBlur={this.onBlur}
          type={type}
          autoComplete="off"
          labeled={Boolean(label)}
        >
          {this.props.children}
        </InputField>
      </InputContainer>
    );
  }
}

==> aiokit-0.2.14.tgz: package/src/components/Input/Input.tsx <==
import React, {Component, ComponentType} from 'react';
import styled, {css} from 'styled-components';

function joinedBorderStyle(joined: IInputProps['joined']) {
  switch (joined) {
    case 'top':
      return css`
        border-radius: 4px 4px 0 0;
      `;
    case 'left':
      return css`
        border-radius: 4px 0 0 4px;
      `;
    case 'bottom':
      return css`
        border-top: 0;
        border-radius: 0 0 4px 4px;
      `;
    case 'right':
      return css`
        border-left: 0;
        border-radius: 0 4px 4px 0;
      `;
    default:
      return css`
        border-radius: 4px;
      `;
  }
}

function borderStyle(flat: boolean, error: string, theme: any): string {
  const {border, danger: red} = theme.color;

  if (flat) {
    return '1px solid transparent';
  }

  return error ? `1px solid ${red}` : `1px solid ${border}`;
}

const InputContainer = styled.div`
  position: relative;
  background-color: ${({theme}) => theme.color.background};
  color: ${({theme}) => theme.color.text};
  min-height: ${({theme}) => theme.font.element};
  border-radius: 4px;
  border: ${({theme, flat, error}) => borderStyle(flat, error, theme)};
  box-sizing: content-box;
  ${({joined}) => joined ? joinedBorderStyle(joined) : null}
`;

const InputField = styled.input`
  outline: none;
  border: 0;
  position: relative;
  width: 100%;
  top: 0;
  left: 0;
  font-family: ${({theme}) => theme.font.family};
  font-size: 16px;
  background-color: transparent;
  padding: ${({theme, labeled}) => labeled ? `28px 20px 10px 20px` : theme.padding.element};
  box-sizing: border-box;
  resize: none;

  &::placeholder {
    color: ${({theme}) => theme.color.placeholder};
    font-size: 14px;
  };
`;

const InputLabel = styled.label`
  position: absolute;
  top: 0;
  left: 0;
  color: ${({theme, error}) => error ? theme.color.danger : theme.color.placeholder};
  font-family: ${({theme}) => theme.font.family};
  font-size: ${({active}) => active ? '12px' : '14px'};
  padding: ${({theme, active}) => active ? `10px ${theme.padding.element}` : theme.padding.element};
  transition-property: padding-top, font-size;
  transition-duration: .2s;
`;

const TextArea = styled.textarea``;

export interface IInputProps {
  onFocus?: (event: React.SyntheticEvent) => void;
  onBlur?: (event: React.SyntheticEvent) => void;
  onChange?: (value: string, name: string) => void;
  value?: string;
  name: string;
  multiline?: boolean;
  placeholder?: string;
  type?: 'text' | 'email' | 'password' | 'number';
  label?: string;
  flat?: boolean;
  joined?: 'top' | 'left' | 'bottom' | 'right';
  error?: string;
  rows?: number;
  as?: ComponentType;
}

export class Input extends Component <IInputProps, any> {
  public static defaultProps = {
    onChange: () => null,
    onBlur: () => null,
    onFocus: () => null,
  };

  public state = {
    value: this.props.value || '',
    prevValue: this.props.value || '',
    active: !!this.props.value,
  };

  public static getDerivedStateFromProps(props, state) {
    const {value} = props;

    if (value !== state.prevValue) {
      return {
        value,
        prevValue: value,
        active: !!value,
      };
    }

    return null;
  }

  private onChange = (event) => {
    const {name, onChange} = this.props;
    const value = event.target ? event.target.value : event;

    this.setState({
      value,
    });

    onChange(value, name);
  };

  private onFocus = (event) => {
    event.persist();

    this.setState({
      active: true,
    });

    this.props.onFocus(event);
  };

  private onBlur = (event) => {
    event.persist();

    this.setState({
      active: this.state.value !== '',
    });

    this.props.onBlur(event);
  };

  public render() {
    const {
      name,
      multiline,
      placeholder,
      type,
      label,
      error,
      flat,
      joined,
      as: AsComponent,
      ...rest
    } = this.props;
    const {active, value} = this.state;

    return (
      <InputContainer
        error={error}
        flat={flat}
        joined={joined}
      >
        {error ?
          <InputLabel active={active} error={error}>{error}</InputLabel>
          : <InputLabel active={active}>{label}</InputLabel>
        }
        <InputField
          {...rest}
          as={multiline ? TextArea : AsComponent}
          name={name}
          placeholder={placeholder}
          value={value}
          onChange={this.onChange}
          onFocus={this.onFocus}
          onBlur={this.onBlur}
          type={type}
          autoComplete="off"
          labeled={Boolean(label)}
        >
          {this.props.children}
        </InputField>
      </InputContainer>
    );
  }
}
